Korzystanie z apigee-ssoadminapi.sh

Edge dla chmury prywatnej w wersji 4.18.01

Moduł logowania jednokrotnego Edge obsługuje 2 rodzaje kont:

  • administrator
  • użytkownik komputera

Narzędzie apigee-ssoadminapi.sh umożliwia zarządzanie administratorami i użytkownikami maszyn powiązanymi z modułem Edge SSO.

Narzędzie apigee-ssoadminapi.sh umożliwia:

  • Wyświetlanie listy administratorów i użytkowników maszyn
  • Dodawanie i usuwanie administratorów oraz użytkowników maszyn
  • Zmień hasło administratora lub użytkowników maszyn.

Użytkownicy z uprawnieniami administratora

Do zarządzania właściwościami modułu logowania jednokrotnego Edge wymagane jest konto administratora w tym module. Potrzebujesz też danych logowania na konto administratora, aby skonfigurować API BaaS lub portal do połączenia z modułem.

Domyślnie podczas instalowania modułu logowania jednokrotnego Edge tworzone jest konto administratora z tymi danymi logowania:

  • username: zdefiniowana przez właściwość SSO_ADMIN_NAME w pliku konfiguracji używanym do konfigurowania modułu logowania jednokrotnego Edge. Wartość domyślna to ssoadmin.
  • password: zdefiniowane przez właściwość SSO_ADMIN_SECRET w pliku konfiguracji używanym do konfigurowania modułu Edge SSO.

Informacje o użytkownikach maszynowych

Użytkownik komputera może uzyskać tokeny OAuth2 bez konieczności podawania hasła. Oznacza to, że możesz całkowicie zautomatyzować proces uzyskiwania i odświeżania tokenów OAuth2 za pomocą interfejsu API zarządzania Google Analytics Edge.

Użytkowników maszynowych używa się zwykle do:

  • Konfigurowanie portalu usług dla programistów do komunikacji z Edge
  • gdy środowisko programistyczne obsługuje automatyzację typowych zadań programistycznych, takich jak automatyzacja testów czy tryb ciągłej integracji/ciągłego wdrażania (CI/CD).

Więcej informacji znajdziesz w artykule Używanie SAML z automatycznymi zadaniami.

Instalowanie apigee-ssoadminapi.sh

Zainstaluj narzędzie apigee-ssoadminapi.sh w węźle serwera zarządzania Edge, na którym zainstalowano moduł SSO Edge. Zwykle narzędzie apigee-ssoadminapi.sh instaluje się podczas instalowania modułu Edge SSO.

Jeśli nie masz jeszcze zainstalowanego narzędzia apigee-ssoadminapi.sh:

  1. Zaloguj się w węźle serwera zarządzania. Na tym węźle powinna być już zainstalowana usługa apigee-service, zgodnie z opisem w artykule Instalowanie narzędzia apigee-setup Edge.
  2. Zainstaluj narzędzie apigee-ssoadminapi.sh, które służy do zarządzania administratorami i użytkownikami maszyn w module logowania jednokrotnego Edge:
    >
    /opt/apigee/apigee-service/bin/apigee-service apigee-ssoadminapi install
  3. Wyloguj się z powłoki, a następnie zaloguj się ponownie, aby dodać narzędzie apigee-ssoadminapi.sh do ścieżki.

Wyświetlanie informacji o apigee-ssoadminapi.sh

Dostępne polecenia narzędzia:

  • admin add
  • admin delete
  • lista administratorów
  • admin setpassword
  • saml machineuser add
  • saml machineuser delete
  • aaml machineuser list
  • saml machineuser setpassword

Informacje o tych poleceniach znajdziesz w pliku /opt/apigee/apigee-ssoadminapi/README.md. Dodatkowo możesz określić opcję „-h” dla każdego polecenia, aby wyświetlić informacje o użyciu. Na przykład to polecenie:

> apigee-ssoadminapi.sh admin list -h

zwraca:

admin list 
  --admin SSOADMIN_CLIENT_NAME      Name of the client having administrative privilege on sso
  --secret SSOADMIN_CLIENT_SECRET   Secret/Password for the client
  --host SSO_HOST                   Hostname of SSO server to connect
  --port SSO_PORT                   Port to use during request
  --ssl SSO_URI_SCHEME              Set to https, defaults to http
  --debug                           Set in debug mode, turns on verbose in curl
  -h                                Displays Help

Wywoływanie narzędzia apigee-ssoadminapi.sh

Narzędzie apigee-ssoadminapi.sh możesz wywołać, przekazując wszystkie właściwości jako argumenty wiersza poleceń, lub w trybie interaktywnym, odpowiadając na prompty.

Aby na przykład podać wszystkie wymagane informacje w wierszu poleceń i wyświetlić listę administratorów:

> apigee-ssoadminapi.sh admin list --admin ssoadmin --secret Secret123 --host 35.197.94.184

zwraca:

[
  {
    "client_id": "ssoadmin",
    "access_token_validity": 300
  }
]

Jeśli pominiesz wymagane informacje, takie jak hasło administratora, pojawi się prośba o ich podanie.

W tym przykładzie pomijasz wartości --port i --ssl, ponieważ moduł Edge SSO używa domyślnych wartości 9099 dla --port i http dla --ssl. Jeśli Twoja instalacja nie używa tych wartości domyślnych, określ je:

> apigee-ssoadminapi.sh admin list --admin ssoadmin --secret Secret123 --host 35.197.94.184 --port 9443 --ssl https

Możesz też użyć interaktywnego formularza, w którym zostaniesz poproszony o podanie wszystkich informacji:

> apigee-ssoadminapi.sh admin list

Pojawi się prośba o podanie wszystkich wymaganych informacji:

SSO admin name (current): ssoadmin
SSO Admin secret (current): 
SSO host: 35.197.94.184